==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Arc/Arc2PH/ts/Arc2PH_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>Arc2PH</name>
    <message>
        <location filename="../Arc2PH.js" line="+65"/>
        <source>Start point</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+9"/>
        <source>End point</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+81"/>
        <source>Invalid height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+7"/>
        <source>The two points are identical</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Arc2PH.ui" line="+17"/>
        <source>Height:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Direction:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Counter Clockwise (Positive)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Clockwise (Negative)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Arc2PHInit.js" line="+2"/>
        <source>2 Points and &amp;Height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw arc from 2 points and height</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Arc/Arc2PH/ts/Arc2PH_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Arc2PH</name>
    <message>
        <location filename="../Arc2PH.js" line="+65"/>
        <source>Start point</source>
        <translation>Punkt początkowy</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>End point</source>
        <translation>Punkt końcowy</translation>
    </message>
    <message>
        <location line="+81"/>
        <source>Invalid height</source>
        <translation>Nieprawidłowa wysokość</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>The two points are identical</source>
        <translation>Te dwa punkty są takie same</translation>
    </message>
    <message>
        <location filename="../Arc2PH.ui" line="+17"/>
        <source>Height:</source>
        <translation>Wysokość:</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Direction:</source>
        <translation>Kierunek:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Counter Clockwise (Positive)</source>
        <translation>Przeciwnie do ruchu wskazówek zegara (w lewo)</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Clockwise (Negative)</source>
        <translation>Zgodnie z ruchem wskazówek zegara (w prawo)</translation>
    </message>
    <message>
        <location filename="../Arc2PHInit.js" line="+2"/>
        <source>2 Points and &amp;Height</source>
        <translation>2 punkty i &amp;wysokość</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw arc from 2 points and height</source>
        <translation>Rysuje łuk przez 2 punkty i o danej wysokości</translation>
    </message>
</context>
</TS>
